#!/bin/sh

set -e

HELPERS_DIR="$(dirname $0)"

. "$HELPERS_DIR/common.sh"

## Do some sanity checks before even trying to start avregd.
# check for config file
if [ ! -r $CONF ]; then
   msg="ERROR: \`$CONF' cannot be read. See $DOC"
   log_failure_msg "$SELF: $msg"
   echo "$msg" | $ERR_LOGGER
   exit 6
fi

# check rights
if [ -n "$STAT" ]; then
   if [ ! "$($STAT --format='%u %g %a' $CONF)" = '0 0 644' ]; then
      msg="WARNING: \`$CONF' must by have rights 0644 root:root. See $DOC"
      log_warning_msg "$SELF: $msg"
      echo "$msg" | $ERR_LOGGER
      chmod 0644 $CONF
      chown root:root $CONF
   fi
fi

storage_dir="$(update-avreg.conf print 'global' --param='storage-dir' -s)"
user="$(update-avreg.conf print 'global' --param='user' -s)"
group="$(update-avreg.conf print 'global' --param='group' -s)"
[ -z "$storage_dir" ] && storage_dir='/var/spool/avreg'
[ -z "$user" ]        && user='avreg'
[ -z "$group" ]       && group='avreg'

# if $storage_dir is mountpoint to XFS (couldn't set uid:gid in fstab)
if [ -n "$storage_dir" ] && mountpoint -q "$storage_dir" ; then
   chmod ${SPOOL_CHMOD:-'0775'} "$storage_dir"
   chown ${SPOOL_CHOWN:-"$user:$group"} "$storage_dir"
fi

# if /var/{run,lock,log}/avreg not exists - maybe mounted to tmpfs
for dir in $RUNDIR $LOCKDIR $LOGDIR ; do
   if [ ! -d "$dir/avreg" ]; then
      mkdir "$dir/avreg"
   fi
   chmod 0775 "$dir/avreg"
   chown "root:$group" "$dir/avreg"
done

