#!/bin/sh
# Включение/выключение записи по расписанию AVReg 6

# в случае ошибки любой из команд (внешних или внутренних)
# - прекращаем работу скрипта
set -e

scriptname=${0##*/}

if [ "$(id -u)" != '0' ]; then
   echo "you must be root or use sudo" 1>&2
   exit 1
fi

db_type=$(update-avreg.conf print --param='db-type' 2>/dev/null | tail -n1)
if [ -z "$db_type" ]; then
   db_type='mysql'
fi
db_name=$(update-avreg.conf print --param='db-name' 2>/dev/null | tail -n1)
if [ -z "$db_name" ]; then
   db_name='avreg6_db'
fi

case "$db_type" in
   [Pp][Gg]*)
      sql_cli='sudo -u postgres psql'
      ;;
   [Mm][Yy]*)
      sql_cli='mysql --defaults-extra-file=/etc/mysql/debian.cnf --default-character-set=utf8 --batch --no-beep'
      ;;
   *)
      echo "unsupported \"db-type\" value - ${db_type}" 1>&2
      exit 1
      ;;
esac

# команда start или stop
cmd="$1"
# используемый режим записи 1(выборочный) или 2(постоянный)
rec_mode=
# список камер, разделённый пробелами
camlist=

usage() {
   cat 1>&2 <<EOF

usage: $scriptname cmd rec_mode [cam_list]
          where: cmd      - "start" or "stop"
                 rec_mode - "selective" or "continuous"
                 cam_list - list of cameras nubmbers separated by space,
                            ie "1 4 5 6 12 14 .. ".
                            if it emptied - use 0 - "default settings".

EOF
   exit 1
}

case "$cmd" in
   start) :
      ;;
   stop) :
      ;;
   *) usage
      ;;
esac
case "$2" in
   sel*) rec_mode=1
      ;;
   con*) rec_mode=2
      ;;
   *) usage
      ;;
esac
if [ "$cmd" = 'stop' ]; then
   motion_detector_value=0
   rec_mode_value=0
else
   motion_detector_value=1
   rec_mode_value=$rec_mode
fi

shift 2

if [ -z "$1" ]; then
   camlist='0'
else
   camlist=$@
fi

sqlfile=$(mktemp)
touch "$sqlfile"
for camnr in $camlist; do
   cat >>"$sqlfile" <<EOF
-- камера ${camnr}
delete from CAMERAS where CAM_NR=${camnr} and PARNAME='rec_mode';
insert into CAMERAS (BIND_MAC, CAM_NR, PARNAME, PARVAL, CHANGE_HOST, CHANGE_USER)
  values('local', ${camnr}, 'rec_mode', '${rec_mode_value}', 'localhost', '$scriptname');
EOF
   if [ "$rec_mode" = '1' ]; then
      cat >>"$sqlfile" <<EOF
delete from CAMERAS where CAM_NR=${camnr} and PARNAME='motion_detector';
insert into CAMERAS (BIND_MAC, CAM_NR, PARNAME, PARVAL, CHANGE_HOST, CHANGE_USER)
  values('local', ${camnr}, 'motion_detector', '${motion_detector_value}', 'localhost', '$scriptname');
EOF
   fi
done

# изменяем параметры камер в базе в таблице CAMERAS
# можно изменять несколько параметров и по разным камерам
$sql_cli "${db_name}" < "$sqlfile" >/dev/null

# перезапускаем avregd только в случае, если он работает в данный момент
# если изменённые параметры не требуют restart, то можно и нужно заменить на reload
for f in $(ls /run/avreg/avregd*.pid 2>/dev/null); do
    kill -HUP $(cat $f)
done

rm -f "$sqlfile"
